<?php 
/**
* Page speed & SEO custom functions and definitions
*
* @package ThemeXL
* @subpackage page-speed-seo
* @since 1.0.0
* @version 1.0.0
*/

/**
* Filters the number of words in an excerpt.
*/
function page_speed_seo_custom_excerpt_length( $length ) {
    if ( is_admin() ) {
        return $length;
    }
    return 50;
}
add_filter( 'excerpt_length', 'page_speed_seo_custom_excerpt_length', 999 );

/**
* Paginate links
*/
function page_speed_seo_paginate_links( $paginate_links ){
	$links = '';
	if( !empty( $paginate_links ) ){

       foreach ( $paginate_links as $paginate_link ) {

          if( strpos( $paginate_link, 'page-numbers current' ) !== false ){
            $paginate_link = str_replace( "<span class='page-numbers current'>", "<a class='active-btn' href='javascript:void(0)'>", $paginate_link );
            $paginate_link = str_replace( "</span>", "</a>", $paginate_link );
            $links .= "<li>".$paginate_link."</li>";
          } 
          else {
            $links .= "<li>".$paginate_link."</li>";
          }
       }
    }
    return $links;
}

/**
* wp_link_pages pagination
*/
function page_speed_seo_link_pages(){
    $link_pages = wp_link_pages( 
    	array(
			'before'           => '',
			'after'            => '',
			'link_before'      => '<span>',
			'link_after'       => '</span>',
			'next_or_number'   => 'number',
			'separator'        => ' ',
			'nextpagelink'     => '<i class="glyphicon glyphicon-chevron-right" aria-hidden="true"></i>',
			'previouspagelink' => '<i class="glyphicon glyphicon-chevron-left" aria-hidden="true"></i>',
			'echo'             => 0
		)
    );

    $link_pages = str_replace( '<a', '<li><a', $link_pages );
    $link_pages = str_replace( '</span></a>', '</a></li>', $link_pages );
    $link_pages = str_replace( '><span>', '>', $link_pages );

    /* active pagination */
    $link_pages = str_replace( '<span>', '<li><a class="active-btn" href="javascript:void(0)">', $link_pages );
    $link_pages = str_replace( '</span>', '</li></a>', $link_pages );

    return $link_pages;
}

/**
* Users comments
*/
function page_speed_seo_users_comments( $comment, $args, $depth ){
	echo '<div class="psseo-comment clearfix">
        <div class="psseo-author-img">
            <img src="'.esc_url( get_avatar_url( $comment ) ).'">
        </div>
        <div class="psseo-comment-info">
            <div class="psseo-author-name">
                <h5>'.get_comment_author().'</h5>
            </div>
            <div class="psseo-user-comment">';
            if ( $comment->comment_approved != '0' ) :
                echo '<p>'.get_comment_text().'</p>';
			else :
		        _e('Your comment is awaiting moderation.', 'page-speed-seo');
		    endif;
            echo '</div>'.
                comment_reply_link(
		           	array_merge( 
		           		$args, 
		           		array(
		           			'reply_text' 	=> '<div class="psseo-comment-reply clearfix"><span>'.__( 'Reply', 'page-speed-seo' ).'</span></div>',
		           			'depth' 		=> $depth, 
		           			'max_depth' 	=> $args['max_depth']
		           			)
		           		)
		           	)
            .'</div>
    </div>';
}