<?php 
/**
* Sets up theme defaults and registers support for various WordPress features.
*
* Note that this function is hooked into the after_setup_theme hook, which
* runs before the init hook. The init hook is too late for some features, such
* as indicating support for post thumbnails.
*
* @package ThemeXL
* @subpackage page-speed-seo
* @since 1.0.0
* @version 1.0.0
*/

function page_speed_seo_theme_support(){
	load_theme_textdomain( 'page-speed-seo' );
    register_nav_menu( 'primary', __( 'Top navigation', 'page-speed-seo' ) );
    add_theme_support( 'automatic-feed-links' ); 
    add_theme_support( 'title-tag' );
    add_theme_support( 'post-formats', array('aside', 'chat', 'gallery', 'link', 'image', 'quote', 'status', 'video', 'audio') );
    add_theme_support( 'post-thumbnails' );
    add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );
    add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );
    add_theme_support( 'custom-logo' );
    add_editor_style();
}
add_action( 'after_setup_theme', 'page_speed_seo_theme_support' );

if( !isset( $content_width ) ) {
	$content_width = 1140;
}

/**
 * Register & Enqueue scripts
 */
add_action( 'wp_enqueue_scripts', 'page_speed_seo_register_scripts', 8 );
add_action( 'wp_enqueue_scripts', 'page_speed_seo_enqueue_scripts', 9 );

function page_speed_seo_register_scripts(){
	
	wp_register_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', null, false, 'all' );
	wp_register_style( 'slicknav', get_template_directory_uri() . '/css/slicknav.css', null, false, 'all' );
	wp_register_style( 'style', get_template_directory_uri() . '/style.css', null, false, 'all' );
	wp_register_script( 'all-js', get_template_directory_uri() . '/js/all_in_one.js', array( 'jquery' ), false, true );
	wp_register_script( 'script-js', get_template_directory_uri() . '/js/script.js', array( 'jquery' ), false, true );
}

function page_speed_seo_enqueue_scripts()
{
	wp_enqueue_style( 'bootstrap' );
	wp_enqueue_style( 'slicknav' );
	wp_enqueue_style( 'style' );

	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'all-js' );
	wp_enqueue_script( 'script-js' );

	if( is_singular() && comments_open() && get_option( 'thread_comments' ) ){
		wp_enqueue_script( 'comment-reply' );
	}
}



